/*
 *  Blunder is an automated tool for analyzing chained exceptions.
 *  Copyright (C) 2009 - Ambrosi Lucas <mailto:lambrosi@users.sourceforge.net>
 *
 *  This file is part of Blunder.
 *
 *  Blunder is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License 
 *  version 3 as published by the Free Software Foundation.
 *
 *  Blunder is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public 
 *  License along with Blunder. If not, see <http://www.gnu.org/licenses/>.
 */

package net.sf.blunder.util;

import java.util.List;

/**
 * Helper class for analysing Exception classes and detecting
 * if they are from client business packages.
 * 
 * @author <a href="mailto:lambrosi@users.sourceforge.net">Ambrosi Lucas</a>
 */
public class BusinessExceptionDetector {

   private List<String> businessPackages;

   /**
    * @param clazz to be analyzed.
    * @return true if the class name belongs to the
    *         business class packages.
    */
   public boolean isBusinessClass( Class<?> clazz ) {
      if ( getBusinessPackages() == null ) {
         return false;
      }
      String className = clazz.getName();
      for ( String bPackage : getBusinessPackages() ) {
         if ( bPackage.charAt( 0 ) == '!' ) {
            if ( !className.startsWith( bPackage.substring( 1 ) ) ) {
               return true;
            }
         }
         if ( className.startsWith( bPackage ) ) {
            return true;
         }
      }
      return false;
   }

   /**
    * @return the business packages list.
    */
   public List<String> getBusinessPackages() {
      return businessPackages;
   }

   /**
    * Sets the business packages list.
    */
   public void setBusinessPackages( List<String> businessPackages ) {
      this.businessPackages = businessPackages;
   }

}
