/*
 *  Blunder is an automated tool for analyzing chained exceptions.
 *  Copyright (C) 2009 - Ambrosi Lucas <mailto:lambrosi@users.sourceforge.net>
 *
 *  This file is part of Blunder.
 *
 *  Blunder is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License 
 *  version 3 as published by the Free Software Foundation.
 *
 *  Blunder is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public 
 *  License along with Blunder. If not, see <http://www.gnu.org/licenses/>.
 */

package net.sf.blunder.util.persistence.translator;

import net.sf.blunder.service.persistence.binary.BlunderBinaryService;
import net.sf.blunder.service.persistence.opencsv.BlunderOpenCsvService;
import org.springframework.context.ApplicationContext;
import org.springframework.context.support.ClassPathXmlApplicationContext;

/**
 * Blunder translator utility.
 * This class can make transformations from Binary to
 * SuperCSV data file.
 * 
 * @author <a href="mailto:lambrosi@users.sourceforge.net">Ambrosi Lucas</a>
 */
public class BinaryToOpenCsv implements ITranslator {

   private ApplicationContext context;

   public BinaryToOpenCsv() {
      context = new ClassPathXmlApplicationContext(
                       new String[] {
                           "classpath:/net/sf/blunder/util/persistence/translator/translation.context.xml" } );
   }

   public void translate() {
      BlunderBinaryService binary = (BlunderBinaryService)context.getBean( "binaryPersistenceService" );
      BlunderOpenCsvService supercsv = (BlunderOpenCsvService)context.getBean( "openCsvPersistenceService" );
      supercsv.setData( binary.getData() );
      supercsv.writeData();
   }

   public static void main( String args[] ) {
      new BinaryToOpenCsv().translate();
   }

}
