/*
 *  Blunder is an automated tool for analyzing chained exceptions.
 *  Copyright (C) 2009 - Ambrosi Lucas <mailto:lambrosi@users.sourceforge.net>
 *
 *  This file is part of Blunder.
 *
 *  Blunder is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License 
 *  version 3 as published by the Free Software Foundation.
 *
 *  Blunder is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public 
 *  License along with Blunder. If not, see <http://www.gnu.org/licenses/>.
 */

package net.sf.blunder.util.persistence.translator;

import java.util.HashMap;
import java.util.List;
import net.sf.blunder.model.ExceptionRelation;
import net.sf.blunder.service.persistence.opencsv.BlunderOpenCsvService;
import org.apache.log4j.Logger;
import org.springframework.context.ApplicationContext;
import org.springframework.context.support.ClassPathXmlApplicationContext;
import org.springframework.orm.hibernate3.HibernateTemplate;

/**
 * Blunder translator utility.
 * This class can make transformations from Hibernate data base to
 * SuperCSV data file.
 * 
 * @author <a href="mailto:lambrosi@users.sourceforge.net">Ambrosi Lucas</a>
 */
public class HibernateToOpenCsv implements ITranslator {

   private static final Logger log = Logger.getLogger( HibernateToOpenCsv.class );

   private ApplicationContext context;

   public HibernateToOpenCsv() {
      context = new ClassPathXmlApplicationContext(
                       new String[] {
                "classpath:/net/sf/blunder/util/persistence/translator/translation.context.xml",
                "classpath:/net/sf/blunder/service/persistence/hibernate/blunder.hibernate-persistence.context.xml" } );
   }

   /**
    *  @see net.sf.blunder.util.persistence.translator.ITranslator#translate()
    */
   public void translate() {
      try {
         log.debug( "Getting template..." );
         HibernateTemplate template = (HibernateTemplate)context.getBean( "blunderHibernateTemplate" );
         log.info( "Lookup all " + ExceptionRelation.class + " on Hibernate..." );
         @SuppressWarnings("all")
         List<ExceptionRelation> all = template.loadAll( ExceptionRelation.class );

         HashMap<Long, ExceptionRelation> map = new HashMap<Long, ExceptionRelation>( all.size() );
         for ( ExceptionRelation er : all ) {
            map.put( er.getId(), er );
         }
         BlunderOpenCsvService opencsv = (BlunderOpenCsvService)context.getBean( "openCsvPersistenceService" );
         opencsv.setData( map );
         opencsv.writeData();

         log.info( "Done!" );
      } catch ( Exception e ) {
         log.fatal( "Error on translation!", e );
      }
   }

   public static void main( String args[] ) {
      new HibernateToOpenCsv().translate();
   }

}
